const cosmos = require("@azure/cosmos");
const queryDocuments = require("./query");
const deleteDocument = require("./delete");
const upsertDocument = require("./upsert");
const headerKeys = ["x-ms-request-charge", "x-ms-throttle-retry-count", "x-ms-throttle-retry-wait-time-ms"];

function logHeaders(command, headers) {
  if (!headers) return;
  let result = { command: command };
  headerKeys.forEach(key => result[key] = headers[key]);
  console.log(result);
}

function create(endpoint, key, database, collection, options) {
  if (!endpoint) throw new Error("endpoint is required");
  if (!key) throw new Error("key is required");
  if (!database) throw new Error("database is required");
  if (!collection) throw new Error("collection is required");

  let client = new cosmos.CosmosClient({ endpoint, key });

  let container = client.database(database).container(collection);

  if (!options) options = { logHeaders: logHeaders };
  if (options.logHeaders === true) options.logHeaders = logHeaders;

  return {
    query: function (query, feedOptions) {
      return queryDocuments(container, query, feedOptions);
    },
    delete: function (document) {
      return deleteDocument(container, document);
    },
    upsert: function (document, requestOptions) {
      return upsertDocument(container, document, requestOptions);
    }
  };
}

module.exports = exports = create;
